# Generated by Django 2.1.14 on 2020-02-06 09:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0044_merge_20200205_1651'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResourceRoleDepartment',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True)),
                ('default', models.BooleanField(default=False)),
                ('department_lead', models.BooleanField(default=False)),
                ('department', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Department')),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Resource')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Role')),
            ],
        ),
        migrations.CreateModel(
            name='ResourceServiceDeskRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True)),
                ('default', models.BooleanField(default=False)),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Resource')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Role')),
            ],
        ),
    ]
