# Generated by Django 3.1.2 on 2021-01-08 13:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0086_auto_20201222_1402'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='phone',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='alternate_phone',
            field=models.CharField(blank=True, max_length=32, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='mobile_phone',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='email_address2',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='email_address3',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]
