# Generated by Django 2.1.11 on 2019-10-30 09:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0019_auto_20191030_0905'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='resource',
            managers=[
            ],
        ),
    ]
