# Generated by Django 3.1.7 on 2022-01-04 13:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0100_auto_20211228_1443'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='taskcategory',
            options={'verbose_name_plural': 'Task categories'},
        ),
    ]
