# Generated by Django 2.1.14 on 2020-06-02 14:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0068_merge_20200521_1615'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicecalltask',
            name='service_call',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.ServiceCall'),
        ),
        migrations.AlterField(
            model_name='servicecallticket',
            name='service_call',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.ServiceCall'),
        ),
    ]
