# Generated by Django 4.0.7 on 2022-11-01 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0110_account_phone'),
    ]

    operations = [
        migrations.AlterField(
            model_name='phase',
            name='estimated_hours',
            field=models.DecimalField(decimal_places=2, default=0.0, max_digits=9),
        ),
    ]
