# Generated by Django 2.1.11 on 2020-04-14 15:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0059_auto_20200414_1242'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicecall',
            name='canceled_by_resource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='cancelled_service_calls', to='djautotask.Resource'),
        ),
        migrations.AlterField(
            model_name='servicecall',
            name='creator_resource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='created_service_calls', to='djautotask.Resource'),
        ),
    ]
