# Generated by Django 2.1.11 on 2020-05-08 11:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0062_task_department'),
    ]

    operations = [
        migrations.CreateModel(
            name='AccountPhysicalLocation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('active', models.BooleanField(default=True)),
                ('account', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Account')),
            ],
            options={
                'ordering': ('name',),
            },
        ),
    ]
